detail

Macro detail 

detail!() { /* proc-macro */ }
Writes a supplementary detail via the Output on Context

Expands to context.output().detail(format!(...)).await.expect("event channel closed"), where context resolves to the local variable in the calling function’s scope. Detail is only shown when the user passes --verbose. This is the macro equivalent of Output::detail.

The macro must be called from an async function because the core Output methods are async.

Examples

use clawless::prelude::*;

#[command]
pub async fn deploy(args: DeployArgs, context: Context) -> CommandResult {
    detail!("config loaded from {}", args.config_path);
    Ok(())
}